@@ -14,7 +14,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -62,7 +62,7 @@ from .type_defs import (
     VpcConfigurationTypeDef,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -74,7 +74,7 @@ __all__ = ("KinesisAnalyticsV2Client",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -98,7 +98,7 @@ class Exceptions:
 
 class KinesisAnalyticsV2Client(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html)
     """
 
@@ -115,14 +115,14 @@ class KinesisAnalyticsV2Client(BaseClient):
         *,
         ApplicationName: str,
         CloudWatchLoggingOption: "CloudWatchLoggingOptionTypeDef",
-        CurrentApplicationVersionId: int = None,
-        ConditionalToken: str = None
+        CurrentApplicationVersionId: int = ...,
+        ConditionalToken: str = ...
     ) -> AddApplicationCloudWatchLoggingOptionResponseTypeDef:
         """
         Adds an Amazon CloudWatch log stream to monitor application configuration
         errors.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_cloud_watch_logging_option)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_cloud_watch_logging_option)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#add_application_cloud_watch_logging_option)
         """
 
@@ -132,7 +132,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         """
         Adds a streaming source to your SQL-based Kinesis Data Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#add_application_input)
         """
 
@@ -148,7 +148,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Adds an  InputProcessingConfiguration to a SQL-based Kinesis Data Analytics
         application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input_processing_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input_processing_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#add_application_input_processing_configuration)
         """
 
@@ -159,7 +159,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Adds an external destination to your SQL-based Kinesis Data Analytics
         application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_output)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_output)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#add_application_output)
         """
 
@@ -174,7 +174,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Adds a reference data source to an existing SQL-based Kinesis Data Analytics
         application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_reference_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_reference_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#add_application_reference_data_source)
         """
 
@@ -183,13 +183,13 @@ class KinesisAnalyticsV2Client(BaseClient):
         *,
         ApplicationName: str,
         VpcConfiguration: "VpcConfigurationTypeDef",
-        CurrentApplicationVersionId: int = None,
-        ConditionalToken: str = None
+        CurrentApplicationVersionId: int = ...,
+        ConditionalToken: str = ...
     ) -> AddApplicationVpcConfigurationResponseTypeDef:
         """
         Adds a Virtual Private Cloud (VPC) configuration to the application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_vpc_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_vpc_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#add_application_vpc_configuration)
         """
 
@@ -197,7 +197,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#can_paginate)
         """
 
@@ -207,16 +207,16 @@ class KinesisAnalyticsV2Client(BaseClient):
         ApplicationName: str,
         RuntimeEnvironment: RuntimeEnvironmentType,
         ServiceExecutionRole: str,
-        ApplicationDescription: str = None,
-        ApplicationConfiguration: "ApplicationConfigurationTypeDef" = None,
-        CloudWatchLoggingOptions: List["CloudWatchLoggingOptionTypeDef"] = None,
-        Tags: List["TagTypeDef"] = None,
-        ApplicationMode: ApplicationModeType = None
+        ApplicationDescription: str = ...,
+        ApplicationConfiguration: "ApplicationConfigurationTypeDef" = ...,
+        CloudWatchLoggingOptions: Sequence["CloudWatchLoggingOptionTypeDef"] = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        ApplicationMode: ApplicationModeType = ...
     ) -> CreateApplicationResponseTypeDef:
         """
         Creates a Kinesis Data Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#create_application)
         """
 
@@ -225,13 +225,13 @@ class KinesisAnalyticsV2Client(BaseClient):
         *,
         ApplicationName: str,
         UrlType: UrlTypeType,
-        SessionExpirationDurationInSeconds: int = None
+        SessionExpirationDurationInSeconds: int = ...
     ) -> CreateApplicationPresignedUrlResponseTypeDef:
         """
         Creates and returns a URL that you can use to connect to an application's
         extension.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#create_application_presigned_url)
         """
 
@@ -241,7 +241,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         """
         Creates a snapshot of the application's state data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#create_application_snapshot)
         """
 
@@ -251,7 +251,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         """
         Deletes the specified application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application)
         """
 
@@ -260,14 +260,14 @@ class KinesisAnalyticsV2Client(BaseClient):
         *,
         ApplicationName: str,
         CloudWatchLoggingOptionId: str,
-        CurrentApplicationVersionId: int = None,
-        ConditionalToken: str = None
+        CurrentApplicationVersionId: int = ...,
+        ConditionalToken: str = ...
     ) -> DeleteApplicationCloudWatchLoggingOptionResponseTypeDef:
         """
         Deletes an Amazon CloudWatch log stream from an Kinesis Data Analytics
         application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_cloud_watch_logging_option)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_cloud_watch_logging_option)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application_cloud_watch_logging_option)
         """
 
@@ -277,7 +277,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         """
         Deletes an  InputProcessingConfiguration from an input.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_input_processing_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_input_processing_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application_input_processing_configuration)
         """
 
@@ -288,7 +288,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Deletes the output destination configuration from your SQL-based Kinesis Data
         Analytics application's configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_output)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_output)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application_output)
         """
 
@@ -299,7 +299,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Deletes a reference data source configuration from the specified SQL-based
         Kinesis Data Analytics application's configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_reference_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_reference_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application_reference_data_source)
         """
 
@@ -313,7 +313,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         """
         Deletes a snapshot of application state.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application_snapshot)
         """
 
@@ -322,23 +322,23 @@ class KinesisAnalyticsV2Client(BaseClient):
         *,
         ApplicationName: str,
         VpcConfigurationId: str,
-        CurrentApplicationVersionId: int = None,
-        ConditionalToken: str = None
+        CurrentApplicationVersionId: int = ...,
+        ConditionalToken: str = ...
     ) -> DeleteApplicationVpcConfigurationResponseTypeDef:
         """
         Removes a VPC configuration from a Kinesis Data Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_vpc_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_vpc_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application_vpc_configuration)
         """
 
     def describe_application(
-        self, *, ApplicationName: str, IncludeAdditionalDetails: bool = None
+        self, *, ApplicationName: str, IncludeAdditionalDetails: bool = ...
     ) -> DescribeApplicationResponseTypeDef:
         """
         Returns information about a specific Kinesis Data Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#describe_application)
         """
 
@@ -348,7 +348,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         """
         Returns information about a snapshot of application state data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#describe_application_snapshot)
         """
 
@@ -358,7 +358,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         """
         Provides a detailed description of a specified version of the application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#describe_application_version)
         """
 
@@ -366,62 +366,62 @@ class KinesisAnalyticsV2Client(BaseClient):
         self,
         *,
         ServiceExecutionRole: str,
-        ResourceARN: str = None,
-        InputStartingPositionConfiguration: "InputStartingPositionConfigurationTypeDef" = None,
-        S3Configuration: "S3ConfigurationTypeDef" = None,
-        InputProcessingConfiguration: "InputProcessingConfigurationTypeDef" = None
+        ResourceARN: str = ...,
+        InputStartingPositionConfiguration: "InputStartingPositionConfigurationTypeDef" = ...,
+        S3Configuration: "S3ConfigurationTypeDef" = ...,
+        InputProcessingConfiguration: "InputProcessingConfigurationTypeDef" = ...
     ) -> DiscoverInputSchemaResponseTypeDef:
         """
         Infers a schema for a SQL-based Kinesis Data Analytics application by evaluating
         sample records on the specified streaming source (Kinesis data stream or Kinesis
         Data Firehose delivery stream) or Amazon S3 object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.discover_input_schema)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.discover_input_schema)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#discover_input_schema)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#generate_presigned_url)
         """
 
     def list_application_snapshots(
-        self, *, ApplicationName: str, Limit: int = None, NextToken: str = None
+        self, *, ApplicationName: str, Limit: int = ..., NextToken: str = ...
     ) -> ListApplicationSnapshotsResponseTypeDef:
         """
         Lists information about the current application snapshots.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_application_snapshots)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_application_snapshots)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#list_application_snapshots)
         """
 
     def list_application_versions(
-        self, *, ApplicationName: str, Limit: int = None, NextToken: str = None
+        self, *, ApplicationName: str, Limit: int = ..., NextToken: str = ...
     ) -> ListApplicationVersionsResponseTypeDef:
         """
         Lists all the versions for the specified application, including versions that
         were rolled back.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_application_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_application_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#list_application_versions)
         """
 
     def list_applications(
-        self, *, Limit: int = None, NextToken: str = None
+        self, *, Limit: int = ..., NextToken: str = ...
     ) -> ListApplicationsResponseTypeDef:
         """
         Returns a list of Kinesis Data Analytics applications in your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_applications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_applications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#list_applications)
         """
 
@@ -429,7 +429,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         """
         Retrieves the list of key-value tags assigned to the application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#list_tags_for_resource)
         """
 
@@ -439,41 +439,41 @@ class KinesisAnalyticsV2Client(BaseClient):
         """
         Reverts the application to the previous running version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.rollback_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.rollback_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#rollback_application)
         """
 
     def start_application(
-        self, *, ApplicationName: str, RunConfiguration: "RunConfigurationTypeDef" = None
+        self, *, ApplicationName: str, RunConfiguration: "RunConfigurationTypeDef" = ...
     ) -> Dict[str, Any]:
         """
         Starts the specified Kinesis Data Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.start_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.start_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#start_application)
         """
 
-    def stop_application(self, *, ApplicationName: str, Force: bool = None) -> Dict[str, Any]:
+    def stop_application(self, *, ApplicationName: str, Force: bool = ...) -> Dict[str, Any]:
         """
         Stops the application from processing data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.stop_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.stop_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#stop_application)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
         """
         Adds one or more key-value tags to a Kinesis Data Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes one or more tags from a Kinesis Data Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#untag_resource)
         """
 
@@ -481,17 +481,17 @@ class KinesisAnalyticsV2Client(BaseClient):
         self,
         *,
         ApplicationName: str,
-        CurrentApplicationVersionId: int = None,
-        ApplicationConfigurationUpdate: "ApplicationConfigurationUpdateTypeDef" = None,
-        ServiceExecutionRoleUpdate: str = None,
-        RunConfigurationUpdate: "RunConfigurationUpdateTypeDef" = None,
-        CloudWatchLoggingOptionUpdates: List["CloudWatchLoggingOptionUpdateTypeDef"] = None,
-        ConditionalToken: str = None
+        CurrentApplicationVersionId: int = ...,
+        ApplicationConfigurationUpdate: "ApplicationConfigurationUpdateTypeDef" = ...,
+        ServiceExecutionRoleUpdate: str = ...,
+        RunConfigurationUpdate: "RunConfigurationUpdateTypeDef" = ...,
+        CloudWatchLoggingOptionUpdates: Sequence["CloudWatchLoggingOptionUpdateTypeDef"] = ...,
+        ConditionalToken: str = ...
     ) -> UpdateApplicationResponseTypeDef:
         """
         Updates an existing Kinesis Data Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.update_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.update_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#update_application)
         """
 
@@ -504,7 +504,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         """
         Updates the maintenance configuration of the Kinesis Data Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.update_application_maintenance_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.update_application_maintenance_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#update_application_maintenance_configuration)
         """
 
@@ -513,7 +513,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         self, operation_name: Literal["list_application_snapshots"]
     ) -> ListApplicationSnapshotsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Paginator.ListApplicationSnapshots)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Paginator.ListApplicationSnapshots)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/paginators.html#listapplicationsnapshotspaginator)
         """
 
@@ -522,6 +522,6 @@ class KinesisAnalyticsV2Client(BaseClient):
         self, operation_name: Literal["list_applications"]
     ) -> ListApplicationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Paginator.ListApplications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Paginator.ListApplications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/paginators.html#listapplicationspaginator)
         """
