@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -33,7 +33,7 @@ from .literals import (
     UrlTypeType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -439,7 +439,7 @@ ApplicationConfigurationTypeDef = TypedDict(
         "EnvironmentProperties": "EnvironmentPropertiesTypeDef",
         "ApplicationCodeConfiguration": "ApplicationCodeConfigurationTypeDef",
         "ApplicationSnapshotConfiguration": "ApplicationSnapshotConfigurationTypeDef",
-        "VpcConfigurations": List["VpcConfigurationTypeDef"],
+        "VpcConfigurations": Sequence["VpcConfigurationTypeDef"],
         "ZeppelinApplicationConfiguration": "ZeppelinApplicationConfigurationTypeDef",
     },
     total=False,
@@ -453,7 +453,7 @@ ApplicationConfigurationUpdateTypeDef = TypedDict(
         "FlinkApplicationConfigurationUpdate": "FlinkApplicationConfigurationUpdateTypeDef",
         "EnvironmentPropertyUpdates": "EnvironmentPropertyUpdatesTypeDef",
         "ApplicationSnapshotConfigurationUpdate": "ApplicationSnapshotConfigurationUpdateTypeDef",
-        "VpcConfigurationUpdates": List["VpcConfigurationUpdateTypeDef"],
+        "VpcConfigurationUpdates": Sequence["VpcConfigurationUpdateTypeDef"],
         "ZeppelinApplicationConfigurationUpdate": "ZeppelinApplicationConfigurationUpdateTypeDef",
     },
     total=False,
@@ -785,8 +785,8 @@ _OptionalCreateApplicationRequestRequestTypeDef = TypedDict(
     {
         "ApplicationDescription": str,
         "ApplicationConfiguration": "ApplicationConfigurationTypeDef",
-        "CloudWatchLoggingOptions": List["CloudWatchLoggingOptionTypeDef"],
-        "Tags": List["TagTypeDef"],
+        "CloudWatchLoggingOptions": Sequence["CloudWatchLoggingOptionTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "ApplicationMode": ApplicationModeType,
     },
     total=False,
@@ -1004,6 +1004,7 @@ DeployAsApplicationConfigurationUpdateTypeDef = TypedDict(
     {
         "S3ContentLocationUpdate": "S3ContentBaseLocationUpdateTypeDef",
     },
+    total=False,
 )
 
 _RequiredDescribeApplicationRequestRequestTypeDef = TypedDict(
@@ -1114,7 +1115,7 @@ DiscoverInputSchemaResponseTypeDef = TypedDict(
 EnvironmentPropertiesTypeDef = TypedDict(
     "EnvironmentPropertiesTypeDef",
     {
-        "PropertyGroups": List["PropertyGroupTypeDef"],
+        "PropertyGroups": Sequence["PropertyGroupTypeDef"],
     },
 )
 
@@ -1129,7 +1130,7 @@ EnvironmentPropertyDescriptionsTypeDef = TypedDict(
 EnvironmentPropertyUpdatesTypeDef = TypedDict(
     "EnvironmentPropertyUpdatesTypeDef",
     {
-        "PropertyGroups": List["PropertyGroupTypeDef"],
+        "PropertyGroups": Sequence["PropertyGroupTypeDef"],
     },
 )
 
@@ -1191,7 +1192,6 @@ GlueDataCatalogConfigurationUpdateTypeDef = TypedDict(
     {
         "DatabaseARNUpdate": str,
     },
-    total=False,
 )
 
 InputDescriptionTypeDef = TypedDict(
@@ -1287,7 +1287,7 @@ InputSchemaUpdateTypeDef = TypedDict(
     {
         "RecordFormatUpdate": "RecordFormatTypeDef",
         "RecordEncodingUpdate": str,
-        "RecordColumnUpdates": List["RecordColumnTypeDef"],
+        "RecordColumnUpdates": Sequence["RecordColumnTypeDef"],
     },
     total=False,
 )
@@ -1805,7 +1805,7 @@ PropertyGroupTypeDef = TypedDict(
     "PropertyGroupTypeDef",
     {
         "PropertyGroupId": str,
-        "PropertyMap": Dict[str, str],
+        "PropertyMap": Mapping[str, str],
     },
 )
 
@@ -1956,7 +1956,7 @@ RunConfigurationTypeDef = TypedDict(
     "RunConfigurationTypeDef",
     {
         "FlinkRunConfiguration": "FlinkRunConfigurationTypeDef",
-        "SqlRunConfigurations": List["SqlRunConfigurationTypeDef"],
+        "SqlRunConfigurations": Sequence["SqlRunConfigurationTypeDef"],
         "ApplicationRestoreConfiguration": "ApplicationRestoreConfigurationTypeDef",
     },
     total=False,
@@ -2045,27 +2045,15 @@ class S3ContentBaseLocationTypeDef(
     pass
 
 
-_RequiredS3ContentBaseLocationUpdateTypeDef = TypedDict(
-    "_RequiredS3ContentBaseLocationUpdateTypeDef",
+S3ContentBaseLocationUpdateTypeDef = TypedDict(
+    "S3ContentBaseLocationUpdateTypeDef",
     {
         "BucketARNUpdate": str,
-    },
-)
-_OptionalS3ContentBaseLocationUpdateTypeDef = TypedDict(
-    "_OptionalS3ContentBaseLocationUpdateTypeDef",
-    {
         "BasePathUpdate": str,
     },
     total=False,
 )
 
-
-class S3ContentBaseLocationUpdateTypeDef(
-    _RequiredS3ContentBaseLocationUpdateTypeDef, _OptionalS3ContentBaseLocationUpdateTypeDef
-):
-    pass
-
-
 _RequiredS3ContentLocationTypeDef = TypedDict(
     "_RequiredS3ContentLocationTypeDef",
     {
@@ -2164,7 +2152,7 @@ _RequiredSourceSchemaTypeDef = TypedDict(
     "_RequiredSourceSchemaTypeDef",
     {
         "RecordFormat": "RecordFormatTypeDef",
-        "RecordColumns": List["RecordColumnTypeDef"],
+        "RecordColumns": Sequence["RecordColumnTypeDef"],
     },
 )
 _OptionalSourceSchemaTypeDef = TypedDict(
@@ -2193,9 +2181,9 @@ SqlApplicationConfigurationDescriptionTypeDef = TypedDict(
 SqlApplicationConfigurationTypeDef = TypedDict(
     "SqlApplicationConfigurationTypeDef",
     {
-        "Inputs": List["InputTypeDef"],
-        "Outputs": List["OutputTypeDef"],
-        "ReferenceDataSources": List["ReferenceDataSourceTypeDef"],
+        "Inputs": Sequence["InputTypeDef"],
+        "Outputs": Sequence["OutputTypeDef"],
+        "ReferenceDataSources": Sequence["ReferenceDataSourceTypeDef"],
     },
     total=False,
 )
@@ -2203,9 +2191,9 @@ SqlApplicationConfigurationTypeDef = TypedDict(
 SqlApplicationConfigurationUpdateTypeDef = TypedDict(
     "SqlApplicationConfigurationUpdateTypeDef",
     {
-        "InputUpdates": List["InputUpdateTypeDef"],
-        "OutputUpdates": List["OutputUpdateTypeDef"],
-        "ReferenceDataSourceUpdates": List["ReferenceDataSourceUpdateTypeDef"],
+        "InputUpdates": Sequence["InputUpdateTypeDef"],
+        "OutputUpdates": Sequence["OutputUpdateTypeDef"],
+        "ReferenceDataSourceUpdates": Sequence["ReferenceDataSourceUpdateTypeDef"],
     },
     total=False,
 )
@@ -2264,7 +2252,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -2291,7 +2279,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -2325,7 +2313,7 @@ _OptionalUpdateApplicationRequestRequestTypeDef = TypedDict(
         "ApplicationConfigurationUpdate": "ApplicationConfigurationUpdateTypeDef",
         "ServiceExecutionRoleUpdate": str,
         "RunConfigurationUpdate": "RunConfigurationUpdateTypeDef",
-        "CloudWatchLoggingOptionUpdates": List["CloudWatchLoggingOptionUpdateTypeDef"],
+        "CloudWatchLoggingOptionUpdates": Sequence["CloudWatchLoggingOptionUpdateTypeDef"],
         "ConditionalToken": str,
     },
     total=False,
@@ -2359,8 +2347,8 @@ VpcConfigurationDescriptionTypeDef = TypedDict(
 VpcConfigurationTypeDef = TypedDict(
     "VpcConfigurationTypeDef",
     {
-        "SubnetIds": List[str],
-        "SecurityGroupIds": List[str],
+        "SubnetIds": Sequence[str],
+        "SecurityGroupIds": Sequence[str],
     },
 )
 
@@ -2373,8 +2361,8 @@ _RequiredVpcConfigurationUpdateTypeDef = TypedDict(
 _OptionalVpcConfigurationUpdateTypeDef = TypedDict(
     "_OptionalVpcConfigurationUpdateTypeDef",
     {
-        "SubnetIdUpdates": List[str],
-        "SecurityGroupIdUpdates": List[str],
+        "SubnetIdUpdates": Sequence[str],
+        "SecurityGroupIdUpdates": Sequence[str],
     },
     total=False,
 )
@@ -2418,7 +2406,7 @@ ZeppelinApplicationConfigurationTypeDef = TypedDict(
         "MonitoringConfiguration": "ZeppelinMonitoringConfigurationTypeDef",
         "CatalogConfiguration": "CatalogConfigurationTypeDef",
         "DeployAsApplicationConfiguration": "DeployAsApplicationConfigurationTypeDef",
-        "CustomArtifactsConfiguration": List["CustomArtifactConfigurationTypeDef"],
+        "CustomArtifactsConfiguration": Sequence["CustomArtifactConfigurationTypeDef"],
     },
     total=False,
 )
@@ -2429,7 +2417,7 @@ ZeppelinApplicationConfigurationUpdateTypeDef = TypedDict(
         "MonitoringConfigurationUpdate": "ZeppelinMonitoringConfigurationUpdateTypeDef",
         "CatalogConfigurationUpdate": "CatalogConfigurationUpdateTypeDef",
         "DeployAsApplicationConfigurationUpdate": "DeployAsApplicationConfigurationUpdateTypeDef",
-        "CustomArtifactsConfigurationUpdate": List["CustomArtifactConfigurationTypeDef"],
+        "CustomArtifactsConfigurationUpdate": Sequence["CustomArtifactConfigurationTypeDef"],
     },
     total=False,
 )
